# -*- coding: utf-8 -*-

# FOGLAMP_BEGIN
# See: http://foglamp-foglamp-documentation.readthedocs-hosted.com
# FOGLAMP_END

""" AWS Things module that handles things object
"""

import json

class AwsThing:
    """ AWS 'Thing' object that represents logical entity created per asset 
    """
    def __init__(self):
        """ Constructor method for AwsThing.
            Args:
                thing_name: 'Thing' name created on AWS IoT.
                thing_type_name: 'Thing Type' name created on AWS IoT.
                attributes: Attributes (key:value pair) attached to thing.
                billing_group: The name of the billing group the thing will be added to.
        """
        self.thing_name = None
        self.thing_type_name = None
        self.attributes = None
        self.billing_group = None

    def set_properties(self, **kwargs):
        """ Setter method for attributes of AWSThing object
        Required Keyword Args:
            thingName: The name of the thing to create. Cannot be changed once created.
            thingTypeName: The name of the thing type associated with the new thing.

        Optional Keyword Args:
            attributePayload: The attribute payload, which consists of up to three name/value pairs in a JSON document.
            billingGroupName : The name of the billing group the thing will be added to.
        """
        for key, value in kwargs.items():
            if key == 'thingName':
                self.thing_name = value
            elif key == 'thingTypeName':
                self.thing_type_name = value
            elif key == 'attributePayload':
                self.attributes = json.dumps(value)
            elif key == 'billingGroup':
                self.billing_group = value

    def __eq__(self, object):
        # guard against matching different class objs
        if self.__class__ != object.__class__:
            return False
        # return True if objects have same values                
        return self.__dict__ == object.__dict__

    def __hash__(self):
        return hash(tuple(sorted(self.__dict__.items())))
    
    